@@ -87,7 +87,7 @@ import logging
 import re
 import time
 from functools import lru_cache
-from typing import Dict
+from typing import Dict, Optional
 from urllib import parse
 
 import requests
@@ -270,9 +270,10 @@ class BiolovisionAPI:
                 # Request returned an error.
                 # Logging and checking if not too many errors to continue
                 logger.error(
-                    _("%s status code = %s, for URL %s"),
+                    _("%s status code: %s, text: %s, for URL %s"),
                     method,
                     resp.status_code,
+                    resp.text,
                     protected_url,
                 )
                 if (self._http_status >= 400) and (
@@ -302,6 +303,8 @@ class BiolovisionAPI:
                     raise HTTPError(resp.status_code)
             else:
                 # No error from request: processing response if needed
+                # Resetting error count after successful transfer
+                self._transfer_errors = 0
                 if method in ["PUT", "DELETE"]:
                     # No response expected
                     resp_chunk = json.loads("{}")
@@ -311,13 +314,22 @@ class BiolovisionAPI:
                             _("Response content: %s, text: %s"), resp, resp.text
                         )
                         # TWEAK: remove extra text outside JSON response
-                        resp_chunk = json.loads(re.findall(r'([\[{].+[}\]])', resp.text)[0])
-                        # resp_chunk = resp.json()
+                        if len(resp.text) > 1:
+                            rsp = re.findall(r'([\[{].*[}\]])', resp.text)
+                            if len(rsp) > 0:
+                                resp_chunk = json.loads(rsp[0])
+                            else:
+                                resp_chunk = {}
+                        else:
+                            resp_chunk = resp.json("{}")
                     except json.decoder.JSONDecodeError:  # pragma: no cover
                         # Error during JSON decoding =>
                         # Logging error and no further processing of empty chunk
                         resp_chunk = json.loads("{}")
                         logger.error(_("Incorrect response content: %s"), resp)
+                    except Exception:
+                        logger.exception(_("Response text causing exception: %s"), resp.text)
+                        raise
 
                 # Initialize or append to response dict, depending on content
                 if "data" in resp_chunk:
@@ -588,19 +600,22 @@ class ObservationsAPI(BiolovisionAPI):
 
     Methods:
 
-    - api_get      - Return a single observations from the controler
+    - api_get         - Return a single observations from the controler
 
-    - api_list     - Return a list of observations from the controler
+    - api_list        - Return a list of observations from the controler
 
-    - api_diff     - Deprecated: Return all changes in observations since a given date
+    - api_diff        - Deprecated: Return all changes in observations since a given date
 
-    - api_search   - Search for observations based on parameter value
+    - api_search      - Search for observations based on parameter value
 
-    - api_create   - Create a single observation
+    - api_create      - Create a single observation
 
-    - api_update   - Update an existing observation
+    - api_update      - Update an existing observation
+
+    - api_delete      - Delete an observation
+
+    - api_delete_list - Delete a list/form
 
-    - api_delete   - Delete an observation
     """
 
     def __init__(self, config, max_retry=None, max_requests=None, max_chunks=None):
@@ -770,6 +785,30 @@ class ObservationsAPI(BiolovisionAPI):
         # DELETE to API
         return super()._url_get(params, "observations/" + id, "DELETE")
 
+    def api_delete_list(self, data: Optional[Dict] = None) -> None:
+        """Deleta a list/form.
+
+        Calls POST on /observations/delete_list/%id% to delete the observation.
+
+        Parameters
+        ----------
+        data: Dict
+            id_form or id_form_universal to delete
+        """
+        # Mandatory parameters.
+        params = {
+            "user_email": self._config.user_email,
+            "user_pw": self._config.user_pw,
+        }
+        logger.debug(_("Delete observation %s"), id)
+        # POST to API
+        if data is not None:
+            res = super()._url_get(params, "observations/delete_list", "POST", body=json.dumps(data))
+        else:
+            logger.warn(_("No parameter passed: call ignored"))
+            res = None
+        return res
+
 
 class ObserversAPI(BiolovisionAPI):
     """Implement api calls to observers controler.
